'use strict';

var clsx = require('clsx');
var React = require('react');
var context = require('./context.js');

const AccordionContent = ({
  children,
  direction = "horizontal"
}) => {
  const container = React.useRef(null);
  const [width, setWidth] = React.useState(void 0);
  const [height, setHeight] = React.useState(void 0);
  const { open } = context.useAccordionContext();
  React.useLayoutEffect(() => {
    const getChildrenDimensions = () => {
      if (!container.current) return;
      const childrenArray2 = Array.from(
        container.current.children || []
      );
      if (direction === "horizontal") {
        const widthSize = childrenArray2.reduce(
          (prev, curr) => prev + curr.clientWidth,
          0
        );
        setWidth(`${widthSize}px`);
      } else {
        const heightSize = childrenArray2.reduce(
          (prev, curr) => prev + curr.clientHeight,
          0
        );
        setHeight(`${heightSize}px`);
      }
    };
    getChildrenDimensions();
    const observer = new ResizeObserver(() => {
      getChildrenDimensions();
    });
    const childrenArray = Array.from(container.current?.children || []);
    childrenArray.forEach((el) => observer.observe(el));
    return () => {
      observer.disconnect();
    };
  }, [direction]);
  return /* @__PURE__ */ React.createElement(
    "div",
    {
      className: clsx(
        `overflow-hidden ease-in-out duration-200`,
        { "transition-[width]": direction === "horizontal" },
        { "w-0": direction === "horizontal" && !open },
        { "transition-[height]": direction === "vertical" },
        { "h-0": direction === "vertical" && !open }
      ),
      style: {
        width: direction === "horizontal" && open ? width : void 0,
        height: direction === "vertical" && open ? height : void 0
      },
      ref: container,
      "data-testid": "accordion-container"
    },
    children
  );
};

exports.AccordionContent = AccordionContent;
