'use strict';

var date = require('@internationalized/date');
var React = require('react');
var reactAria = require('react-aria');
var reactStately = require('react-stately');
var DateSegment = require('./DateSegment.js');

const formatLiteralSegment = (text) => {
  return text.includes(",") ? text.replace(/,/g, " ") : text;
};
const DateField = ({
  onClickDate,
  onClickTime,
  ...props
}) => {
  const { locale } = reactAria.useLocale();
  const state = reactStately.useDateFieldState({
    ...props,
    createCalendar: date.createCalendar,
    locale
  });
  const ref = React.useRef(null);
  const { fieldProps } = reactAria.useDateField(
    { "aria-label": "date-field" },
    state,
    ref
  );
  const handleOnClickSegment = React.useCallback(
    (segment) => {
      if (!segment.isEditable || state.isDisabled) return;
      if (["hour", "minute", "second"].includes(segment.type)) {
        onClickTime?.();
      }
      if (["year", "month", "day"].includes(segment.type)) {
        onClickDate?.();
      }
    },
    [onClickDate, onClickTime, state.isDisabled]
  );
  return /* @__PURE__ */ React.createElement(
    "div",
    {
      ...fieldProps,
      ref,
      className: "flex flex-row",
      "data-testid": "date-field-div"
    },
    state.segments.map((segment, i) => {
      if (segment.type === "literal") {
        const text = formatLiteralSegment(segment.text);
        return /* @__PURE__ */ React.createElement("span", { key: i, style: { whiteSpace: "pre" } }, text);
      }
      return /* @__PURE__ */ React.createElement("div", { key: i, onClick: () => handleOnClickSegment(segment) }, /* @__PURE__ */ React.createElement(DateSegment.DateSegment, { segment, state }));
    })
  );
};

exports.DateField = DateField;
