'use strict';

var React = require('react');
require('@internationalized/date');
require('react-aria');
require('react-stately');
var date = require('../../utils/date.js');
var useDatePickerInput = require('../../hooks/useDatePickerInput.js');
var useDatePickerInputCommon = require('../../hooks/useDatePickerInputCommon.js');
require('react-dropzone');
require('uuid');
require('@floating-ui/react');
require('currency.js');
var Calendar = require('../Calendar/Calendar.js');
var index = require('../Popover/index.js');
var Content = require('../Select/Content.js');
var DateField = require('./DateField.js');
var DatePickerInputBase = require('./DatePickerInputBase.js');

const DatePickerInputWithPopover = (props) => {
  const {
    onChange,
    value,
    label,
    variants,
    disabled,
    hourCycle = 24,
    granularity = "day"
  } = props;
  const { fieldProps, state, ref } = useDatePickerInput.useDatePickerInput({
    value,
    onChange
  });
  const { handleTogglePopover, handleChangeCalendar, handleCloseCalendar } = useDatePickerInputCommon.useDatePickerInputCommon({
    onChangeCalendar: (value2) => {
      state.setValue(date.dateToCalendarDateTime(value2));
    }
  });
  return /* @__PURE__ */ React.createElement("div", { ref, "data-testid": "date-picker-input" }, /* @__PURE__ */ React.createElement(index.Popover.Trigger, { disabled: true }, /* @__PURE__ */ React.createElement(
    DatePickerInputBase.DatePickerInputBase,
    {
      variants: {
        ...variants,
        intent: state.isInvalid ? "error" : variants?.intent
      },
      label,
      disabled,
      value,
      onClean: () => state.setValue(null),
      onToggle: handleTogglePopover
    },
    /* @__PURE__ */ React.createElement(
      DateField.DateField,
      {
        ...fieldProps,
        onChange: (value2) => {
          fieldProps.onChange?.(value2);
          handleCloseCalendar();
        },
        isDisabled: disabled,
        onClickDate: handleTogglePopover,
        hourCycle,
        granularity
      }
    )
  )), /* @__PURE__ */ React.createElement(
    index.Popover.Content,
    {
      className: "bg-inherit shadow-none border-none",
      initialFocus: -1
    },
    /* @__PURE__ */ React.createElement(Calendar.Calendar, { value, onChange: handleChangeCalendar })
  ));
};
const DatePickerInput = (props) => /* @__PURE__ */ React.createElement(index.Popover.Root, { placement: "bottom-start", trigger: "click" }, /* @__PURE__ */ React.createElement(Content.Content, null, /* @__PURE__ */ React.createElement(DatePickerInputWithPopover, { ...props })));

exports.DatePickerInput = DatePickerInput;
