'use strict';

var React = require('react');
require('@internationalized/date');
require('react-aria');
require('react-stately');
var date = require('../../utils/date.js');
var useDatePickerInputCommon = require('../../hooks/useDatePickerInputCommon.js');
var useDateRangePickerInput = require('../../hooks/useDateRangePickerInput.js');
require('react-dropzone');
require('uuid');
require('@floating-ui/react');
require('currency.js');
var RangeCalendar = require('../Calendar/RangeCalendar.js');
var index = require('../Popover/index.js');
var Content = require('./Content.js');
var DateField = require('./DateField.js');
var DatePickerInputBase = require('./DatePickerInputBase.js');

const DateRangePickerInputWithPopover = (props) => {
  const {
    onChange,
    value,
    label,
    variants,
    disabled = false,
    hourCycle = 24,
    granularity = "day"
  } = props;
  const { endFieldProps, startFieldProps, ref, state } = useDateRangePickerInput.useDateRangePickerInput({ value, onChange });
  const { handleTogglePopover, handleChangeCalendar, handleCloseCalendar } = useDatePickerInputCommon.useDatePickerInputCommon({
    onChangeRangeCalendar: (value2) => {
      state.setDateRange({
        start: date.dateToCalendarDateTime(value2?.start),
        end: date.dateToCalendarDateTime(value2?.end)
      });
    }
  });
  return /* @__PURE__ */ React.createElement("div", { ref, "data-testid": "date-range-picker-input" }, /* @__PURE__ */ React.createElement(index.Popover.Trigger, { disabled: true }, /* @__PURE__ */ React.createElement(
    DatePickerInputBase.DatePickerInputBase,
    {
      variants: {
        ...variants,
        intent: state.isInvalid ? "error" : variants?.intent
      },
      label,
      disabled,
      value,
      onClean: () => state.setValue(null),
      onToggle: handleTogglePopover
    },
    /* @__PURE__ */ React.createElement("div", { className: "flex flex-row gap-x-micro items-center" }, /* @__PURE__ */ React.createElement(
      DateField.DateField,
      {
        ...startFieldProps,
        onChange: (value2) => {
          startFieldProps.onChange?.(value2);
          handleCloseCalendar();
        },
        isDisabled: disabled,
        onClickDate: handleTogglePopover,
        hourCycle,
        granularity
      }
    ), /* @__PURE__ */ React.createElement("span", null, "-"), /* @__PURE__ */ React.createElement(
      DateField.DateField,
      {
        ...endFieldProps,
        onChange: (value2) => {
          endFieldProps.onChange?.(value2);
          handleCloseCalendar();
        },
        isDisabled: disabled,
        onClickDate: handleTogglePopover,
        hourCycle,
        granularity
      }
    ))
  )), /* @__PURE__ */ React.createElement(
    index.Popover.Content,
    {
      className: "bg-inherit shadow-none border-none",
      initialFocus: -1
    },
    /* @__PURE__ */ React.createElement(RangeCalendar.RangeCalendar, { value, onChange: handleChangeCalendar })
  ));
};
const DateRangePickerInput = (props) => /* @__PURE__ */ React.createElement(index.Popover.Root, { placement: "bottom-start", trigger: "click" }, /* @__PURE__ */ React.createElement(Content.Content, null, /* @__PURE__ */ React.createElement(DateRangePickerInputWithPopover, { ...props })));

exports.DateRangePickerInput = DateRangePickerInput;
