'use strict';

var React = require('react');
require('@internationalized/date');
require('react-aria');
require('react-stately');
require('../Popover/Context.js');
require('react-dropzone');
require('uuid');
require('@floating-ui/react');
var useNumberMask = require('../../hooks/useNumberMask.js');
var useStringMask = require('../../hooks/useStringMask.js');
var Root = require('./Root.js');

const InputMask = React.forwardRef(
  ({ mask, onChange, value, ...rest }, ref) => {
    const getInputHook = (value2) => {
      if (mask !== void 0) {
        if (Array.isArray(mask) || typeof mask === "function") {
          return useStringMask.useStringMask(mask, value2);
        } else {
          return useNumberMask.useNumberMask(mask, value2);
        }
      } else {
        return [void 0, void 0];
      }
    };
    const [maskValue, setMaskValue] = getInputHook(value ?? "");
    const _value = maskValue === void 0 ? value?.toString() : maskValue.formatted ? maskValue.formatted : "";
    React.useEffect(() => {
      if (onChange) {
        onChange(maskValue?.raw);
      }
    }, [maskValue]);
    const onChangeValue = React.useCallback(
      (value2) => {
        if (maskValue !== void 0 && setMaskValue !== void 0) {
          setMaskValue(value2);
        } else onChange?.(value2);
      },
      [value]
    );
    React.useEffect(() => {
      if (maskValue !== void 0 && setMaskValue !== void 0 && value !== void 0 && typeof maskValue === "object") {
        if (maskValue.raw !== void 0 && maskValue.raw.toString() !== value.toString()) {
          onChangeValue(value);
        }
      } else if (maskValue === void 0 && value !== void 0) {
        onChangeValue(value);
      }
    }, [value]);
    return /* @__PURE__ */ React.createElement(
      Root.InputRoot,
      {
        ...rest,
        value: _value,
        onChange: (e) => onChangeValue(e.target.value),
        ref
      }
    );
  }
);

exports.InputMask = InputMask;
