'use strict';

var clsx = require('clsx');
var React = require('react');

const Masonry = ({ children, columns }) => {
  const getColumns = () => {
    const columnsArray = Array.from(
      { length: columns },
      () => []
    );
    React.Children.forEach(children, (child, index) => {
      if (child && React.isValidElement(child)) {
        columnsArray[index % columns].push(child);
      }
    });
    return columnsArray;
  };
  const renderColumn = (column) => {
    return column.map((item, index) => {
      return /* @__PURE__ */ React.createElement("div", { className: index > 0 ? "mt-deca" : "mt-0", key: index }, item);
    });
  };
  const renderColumns = () => {
    return getColumns().map((column, index) => {
      return /* @__PURE__ */ React.createElement(
        "div",
        {
          className: clsx(
            "width-0 flex flex-1 flex-col content-start",
            index > 0 ? "ml-deca" : "ml-0"
          ),
          key: index
        },
        renderColumn(column)
      );
    });
  };
  return /* @__PURE__ */ React.createElement(
    "div",
    {
      "data-testid": "masonry",
      className: "box-border flex w-full flex-row content-stretch justify-center"
    },
    renderColumns()
  );
};

module.exports = Masonry;
