'use strict';

var clsx = require('clsx');
var React = require('react');
require('@internationalized/date');
require('react-aria');
require('react-stately');
require('../Popover/Context.js');
require('react-dropzone');
require('uuid');
require('@floating-ui/react');
require('currency.js');
require('../../provider/MenubarContext.js');
require('../../provider/SnackbarProvider.js');
var useMenubar = require('../../provider/useMenubar.js');
var menubar = require('../../styles/menubar.js');
var IconControlSubItem = require('./IconControlSubItem.js');
var ItemLink = require('./ItemLink.js');
var CategoriesContext = require('../../provider/CategoriesContext.js');

const { container, textBehavior } = menubar.item();
const Item = ({
  children,
  subItems,
  renderSubItems,
  className,
  anchorProps,
  title,
  parentCategoryTitle,
  ...rest
}) => {
  const hasSubItems = (subItems ?? []).length > 0;
  const [, setShow] = useMenubar.useMenubar();
  const { expandedMenus, toggleSubmenu } = CategoriesContext.useCategories();
  const isExpanded = expandedMenus[parentCategoryTitle] === title;
  const handleClickItemMenubar = React.useCallback(
    (e) => {
      if (hasSubItems) {
        e.stopPropagation();
        toggleSubmenu(parentCategoryTitle, title);
      } else {
        setShow(false);
      }
    },
    [hasSubItems, parentCategoryTitle, title, toggleSubmenu, setShow]
  );
  return /* @__PURE__ */ React.createElement(ItemLink, { anchorProps }, /* @__PURE__ */ React.createElement(
    "div",
    {
      "data-testid": "item-menubar",
      ...rest,
      onClick: handleClickItemMenubar,
      className: clsx(
        container({ className }),
        (!hasSubItems || anchorProps) && textBehavior()
      )
    },
    children,
    hasSubItems ? /* @__PURE__ */ React.createElement(
      IconControlSubItem,
      {
        show: isExpanded,
        setShow: () => toggleSubmenu(parentCategoryTitle, title)
      }
    ) : null
  ), isExpanded ? /* @__PURE__ */ React.createElement(React.Fragment, null, subItems?.map((subItem) => renderSubItems?.(subItem))) : null);
};

module.exports = Item;
