'use strict';

var React = require('react');
var io5 = require('react-icons/io5');
var index = require('../Popover/index.js');
var context = require('./context.js');
var clsx = require('clsx');
var cortexCore = require('@tecsinapse/cortex-core');

const { button } = cortexCore.selectVariants();
const SelectTrigger = ({
  label,
  placeholder,
  disabled,
  multiLabelSelected,
  ...rest
}) => {
  const { value, labelExtractor, setTriggerWidth } = React.useContext(context.SelectContext);
  const triggerRef = React.useRef(null);
  const _placeholder = React.useMemo(() => {
    if (value?.length === 0 || !value) return placeholder ?? label;
    if (value?.length === 1) return labelExtractor(value[0]);
    if (value?.length > 1)
      return multiLabelSelected ? multiLabelSelected(value.length) : `${value.length} items selected`;
    return labelExtractor(value);
  }, [label, value]);
  const hasValue = Array.isArray(value) ? value.length > 0 : !!value;
  React.useEffect(() => {
    if (triggerRef.current && setTriggerWidth) {
      const width = triggerRef.current.getBoundingClientRect().width;
      setTriggerWidth(width);
    }
  }, [triggerRef.current, setTriggerWidth]);
  return /* @__PURE__ */ React.createElement(index.Popover.Trigger, { disabled }, /* @__PURE__ */ React.createElement("div", { className: "w-full gap-mili" }, /* @__PURE__ */ React.createElement(
    "button",
    {
      ref: triggerRef,
      className: button({ className: rest.className }),
      disabled,
      role: "button",
      ...rest
    },
    /* @__PURE__ */ React.createElement(
      "span",
      {
        className: clsx({ "mt-mili": hasValue && label }),
        "data-testid": "select-placeholder"
      },
      _placeholder
    ),
    /* @__PURE__ */ React.createElement(io5.IoChevronDownOutline, null)
  ), hasValue && label ? /* @__PURE__ */ React.createElement(
    "label",
    {
      htmlFor: "select-trigger",
      className: clsx(
        "ml-centi",
        cortexCore.labelStyle({ intent: "default", placeholder })
      ),
      "data-testid": "input-label"
    },
    label
  ) : null));
};

exports.SelectTrigger = SelectTrigger;
