'use strict';

var React = require('react');
var Node = require('./Node.js');
var clsx = require('clsx');

const Root = ({
  segmented = false,
  children,
  className = "",
  interactive = true
}) => {
  const initialSelectedIndex = React.useMemo(() => {
    let initialIndex = null;
    React.Children.forEach(children, (child, index) => {
      if (React.isValidElement(child) && child.props.selected) {
        initialIndex = index;
      }
    });
    return initialIndex;
  }, [children]);
  const [selectedNode, setSelectedNode] = React.useState(
    initialSelectedIndex
  );
  const childrenCount = React.useMemo(
    () => React.Children.count(children),
    [children]
  );
  const handleNodeClick = React.useCallback(
    (index, onClick) => {
      if (interactive) {
        setSelectedNode(index);
        if (onClick) {
          onClick();
        }
      }
    },
    [interactive]
  );
  const renderNode = React.useMemo(
    () => (child, index) => {
      if (React.isValidElement(child) && child.type === Node.Node) {
        return React.cloneElement(child, {
          isFirst: index === 0,
          isLast: index === childrenCount - 1,
          selected: selectedNode === index,
          segmented,
          interactive,
          onClick: () => handleNodeClick(index, child.props.onClick)
        });
      }
      return null;
    },
    [childrenCount, selectedNode, segmented, interactive]
  );
  return /* @__PURE__ */ React.createElement(
    "div",
    {
      className: clsx(
        "flex w-full space-x-2 bg-white p-4 pb-2 rounded-mili",
        className
      )
    },
    React.Children.map(children, renderNode)
  );
};

exports.Root = Root;
