'use strict';

var date = require('@internationalized/date');
var React = require('react');
var reactAria = require('react-aria');

const useCalendarCell = ({ state, date: date$1 }) => {
  const ref = React.useRef(null);
  const {
    cellProps,
    buttonProps,
    isSelected,
    isOutsideVisibleRange,
    formattedDate
  } = reactAria.useCalendarCell({ date: date$1 }, state, ref);
  const rangeStateHighlitedRange = state?.highlightedRange;
  const isSameDayStart = rangeStateHighlitedRange && date$1 ? date.isSameDay(date$1, rangeStateHighlitedRange.start) : void 0;
  const isSameDayEnd = rangeStateHighlitedRange && date$1 ? date.isSameDay(date$1, rangeStateHighlitedRange.end) : void 0;
  const isSelectionStart = isSameDayStart && !isSameDayEnd;
  const isSelectionEnd = isSameDayEnd && !isSameDayStart;
  const inRange = rangeStateHighlitedRange && date$1 > rangeStateHighlitedRange?.start && date$1 < rangeStateHighlitedRange?.end;
  return {
    ref,
    cellProps,
    buttonProps,
    isSelected,
    isOutsideVisibleRange,
    formattedDate,
    isSelectionStart,
    isSelectionEnd,
    inRange: Boolean(inRange)
  };
};

exports.useCalendarCell = useCalendarCell;
