'use strict';

var React = require('react');
var reactAria = require('react-aria');
var reactStately = require('react-stately');
var date = require('../utils/date.js');

const useDatePickerInput = ({
  value,
  onChange
}) => {
  const state = reactStately.useDatePickerState({
    defaultValue: value ? date.dateToCalendarDateTime(value) : null,
    onChange: (value2) => {
      onChange(date.calendarDateToDate(value2));
    }
  });
  const ref = React.useRef(null);
  const { fieldProps } = reactAria.useDatePicker(
    { "aria-label": "date-picker-field" },
    state,
    ref
  );
  React.useEffect(() => {
    if (!value) {
      state.setValue(null);
    }
  }, [value]);
  return {
    fieldProps,
    state,
    ref
  };
};

exports.useDatePickerInput = useDatePickerInput;
