'use strict';

var React = require('react');
var reactAria = require('react-aria');
var reactStately = require('react-stately');
var date = require('../utils/date.js');

const useDateRangePickerInput = ({
  value,
  onChange
}) => {
  const state = reactStately.useDateRangePickerState({
    defaultValue: value ? {
      start: date.dateToCalendarDateTime(value?.start),
      end: date.dateToCalendarDateTime(value?.end)
    } : null,
    onChange: (value2) => {
      onChange({
        start: value2 ? date.calendarDateToDate(value2.start) : void 0,
        end: value2 ? date.calendarDateToDate(value2.end) : void 0
      });
    }
  });
  const ref = React.useRef(null);
  const { startFieldProps, endFieldProps } = reactAria.useDateRangePicker(
    { "aria-label": "date-range-picker-field" },
    state,
    ref
  );
  return {
    startFieldProps,
    endFieldProps,
    state,
    ref
  };
};

exports.useDateRangePickerInput = useDateRangePickerInput;
