'use strict';

var React = require('react');

function useDebouncedState(initialState, timeoutCallback, timeoutMs = 166) {
  const timeoutId = React.useRef();
  const [state, setState] = React.useState(initialState);
  React.useEffect(() => {
    if (timeoutId.current) clearTimeout(timeoutId.current);
    if (timeoutCallback)
      timeoutId.current = setTimeout(() => timeoutCallback(state), timeoutMs);
  }, [state]);
  return [state, setState];
}

exports.useDebouncedState = useDebouncedState;
