'use strict';

var react = require('@floating-ui/react');
var React = require('react');

const useFloatingElement = ({
  placement,
  trigger,
  delay,
  arrowRef,
  controlled,
  isOpen,
  setIsOpen,
  fallbackPlacements = ["right", "bottom", "left", "top"]
}) => {
  const [openUncontrolled, onOpenChangeUncontrolled] = React.useState(false);
  const { x, y, strategy, refs, update, context, floatingStyles } = react.useFloating(
    {
      placement,
      whileElementsMounted: react.autoUpdate,
      open: controlled ? isOpen : openUncontrolled,
      onOpenChange: controlled ? setIsOpen : onOpenChangeUncontrolled,
      middleware: [
        react.offset(10),
        react.flip({
          flipAlignment: true,
          fallbackPlacements
        }),
        react.shift(),
        ...arrowRef ? [react.arrow({ element: arrowRef })] : []
      ]
    }
  );
  const click = react.useClick(context, { enabled: trigger === "click" });
  const dismiss = react.useDismiss(context);
  const role = react.useRole(context);
  const hover = react.useHover(context, {
    enabled: trigger === "hover",
    delay,
    handleClose: react.safePolygon()
  });
  const { getReferenceProps, getFloatingProps } = react.useInteractions([
    click,
    dismiss,
    role,
    hover
  ]);
  React.useEffect(() => {
    if (controlled && isOpen) update();
    else if (openUncontrolled) update();
  }, [openUncontrolled, update, isOpen]);
  const triggerProps = {
    ref: refs.setReference,
    ...getReferenceProps()
  };
  return {
    isOpen: controlled ? isOpen : openUncontrolled,
    setIsOpen: controlled ? setIsOpen : onOpenChangeUncontrolled,
    x,
    y,
    strategy,
    refs,
    context,
    floatingStyles,
    triggerProps,
    getReferenceProps,
    getFloatingProps
  };
};

exports.useFloatingElement = useFloatingElement;
