'use strict';

var currency = require('currency.js');
var React = require('react');
require('@internationalized/date');
var extractors = require('../utils/extractors.js');

const getRegex = (precision) => new RegExp(`\\B(?=(\\d{${precision}})(?!\\d))`, "g");
const getInternalNumberAndMask = (value, options) => {
  const mergedOptions = { ...options };
  const { precision = -1 } = mergedOptions;
  let internalNumber;
  if (typeof value === "number") {
    if (precision) {
      let stringValue = String(value);
      const decimalIndex = stringValue.indexOf(".");
      const currentPrecision = decimalIndex + precision;
      if (decimalIndex !== -1 && currentPrecision <= stringValue.length) {
        const zeros = stringValue.length + 1 - currentPrecision;
        for (let i = 0; i < zeros; i++) stringValue = stringValue + `0`;
      }
      internalNumber = Number(stringValue);
    } else {
      internalNumber = value;
    }
  } else {
    const onlyNumbers = String(extractors.extractNumbersFromString(value));
    const padZeros = String(onlyNumbers).padStart(precision + 1, "0");
    internalNumber = Number(padZeros.replace(getRegex(precision), "."));
  }
  if (internalNumber > Number.MAX_SAFE_INTEGER) {
    internalNumber = Number.MAX_SAFE_INTEGER;
  }
  if (internalNumber < Number.MIN_SAFE_INTEGER) {
    internalNumber = Number.MIN_SAFE_INTEGER;
  }
  return {
    internalNumber,
    mergedOptions
  };
};
const applyNumberMask = (value, options) => {
  const { internalNumber, mergedOptions } = getInternalNumberAndMask(
    value ?? 0,
    options
  );
  return {
    raw: internalNumber,
    formatted: currency(internalNumber, mergedOptions).format()
  };
};
const useNumberMask = (options, defaultValue) => {
  const [value, setValue] = React.useState(
    applyNumberMask(defaultValue, options)
  );
  const handleChangeValue = React.useCallback(
    (formattedValue) => {
      const { raw, formatted } = applyNumberMask(formattedValue, options);
      setValue({
        raw,
        formatted
      });
    },
    [setValue]
  );
  return [value, handleChangeValue];
};

exports.applyNumberMask = applyNumberMask;
exports.getInternalNumberAndMask = getInternalNumberAndMask;
exports.useNumberMask = useNumberMask;
