'use strict';

var React = require('react');

const useOutsideClickListener = ({
  ref,
  onClickOutside
}) => {
  const handleClickOutside = React.useCallback((event) => {
    if (ref.current && !ref.current.contains(event.composedPath()[0])) {
      onClickOutside?.();
    }
  }, []);
  React.useEffect(() => {
    document.addEventListener("click", handleClickOutside, true);
    return () => {
      document.removeEventListener("click", handleClickOutside, true);
    };
  }, [handleClickOutside]);
};

exports.useOutsideClickListener = useOutsideClickListener;
