import { createCalendar } from '@internationalized/date';
import React__default, { useCallback } from 'react';
import { useLocale, useDateField } from 'react-aria';
import { useDateFieldState } from 'react-stately';
import { DateSegment } from './DateSegment.js';

const formatLiteralSegment = (text) => {
  return text.includes(",") ? text.replace(/,/g, " ") : text;
};
const DateField = ({
  onClickDate,
  onClickTime,
  ...props
}) => {
  const { locale } = useLocale();
  const state = useDateFieldState({
    ...props,
    createCalendar,
    locale
  });
  const ref = React__default.useRef(null);
  const { fieldProps } = useDateField(
    { "aria-label": "date-field" },
    state,
    ref
  );
  const handleOnClickSegment = useCallback(
    (segment) => {
      if (!segment.isEditable || state.isDisabled) return;
      if (["hour", "minute", "second"].includes(segment.type)) {
        onClickTime?.();
      }
      if (["year", "month", "day"].includes(segment.type)) {
        onClickDate?.();
      }
    },
    [onClickDate, onClickTime, state.isDisabled]
  );
  return /* @__PURE__ */ React__default.createElement(
    "div",
    {
      ...fieldProps,
      ref,
      className: "flex flex-row",
      "data-testid": "date-field-div"
    },
    state.segments.map((segment, i) => {
      if (segment.type === "literal") {
        const text = formatLiteralSegment(segment.text);
        return /* @__PURE__ */ React__default.createElement("span", { key: i, style: { whiteSpace: "pre" } }, text);
      }
      return /* @__PURE__ */ React__default.createElement("div", { key: i, onClick: () => handleOnClickSegment(segment) }, /* @__PURE__ */ React__default.createElement(DateSegment, { segment, state }));
    })
  );
};

export { DateField };
