import React__default from 'react';
import '@internationalized/date';
import 'react-aria';
import 'react-stately';
import { dateToCalendarDateTime } from '../../utils/date.js';
import { useDatePickerInput } from '../../hooks/useDatePickerInput.js';
import { useDatePickerInputCommon } from '../../hooks/useDatePickerInputCommon.js';
import 'react-dropzone';
import 'uuid';
import '@floating-ui/react';
import 'currency.js';
import { Calendar } from '../Calendar/Calendar.js';
import { Popover } from '../Popover/index.js';
import { Content } from '../Select/Content.js';
import { DateField } from './DateField.js';
import { DatePickerInputBase } from './DatePickerInputBase.js';

const DatePickerInputWithPopover = (props) => {
  const {
    onChange,
    value,
    label,
    variants,
    disabled,
    hourCycle = 24,
    granularity = "day"
  } = props;
  const { fieldProps, state, ref } = useDatePickerInput({
    value,
    onChange
  });
  const { handleTogglePopover, handleChangeCalendar, handleCloseCalendar } = useDatePickerInputCommon({
    onChangeCalendar: (value2) => {
      state.setValue(dateToCalendarDateTime(value2));
    }
  });
  return /* @__PURE__ */ React__default.createElement("div", { ref, "data-testid": "date-picker-input" }, /* @__PURE__ */ React__default.createElement(Popover.Trigger, { disabled: true }, /* @__PURE__ */ React__default.createElement(
    DatePickerInputBase,
    {
      variants: {
        ...variants,
        intent: state.isInvalid ? "error" : variants?.intent
      },
      label,
      disabled,
      value,
      onClean: () => state.setValue(null),
      onToggle: handleTogglePopover
    },
    /* @__PURE__ */ React__default.createElement(
      DateField,
      {
        ...fieldProps,
        onChange: (value2) => {
          fieldProps.onChange?.(value2);
          handleCloseCalendar();
        },
        isDisabled: disabled,
        onClickDate: handleTogglePopover,
        hourCycle,
        granularity
      }
    )
  )), /* @__PURE__ */ React__default.createElement(
    Popover.Content,
    {
      className: "bg-inherit shadow-none border-none",
      initialFocus: -1
    },
    /* @__PURE__ */ React__default.createElement(Calendar, { value, onChange: handleChangeCalendar })
  ));
};
const DatePickerInput = (props) => /* @__PURE__ */ React__default.createElement(Popover.Root, { placement: "bottom-start", trigger: "click" }, /* @__PURE__ */ React__default.createElement(Content, null, /* @__PURE__ */ React__default.createElement(DatePickerInputWithPopover, { ...props })));

export { DatePickerInput };
