import React__default from 'react';
import '@internationalized/date';
import 'react-aria';
import 'react-stately';
import { dateToCalendarDateTime } from '../../utils/date.js';
import { useDatePickerInputCommon } from '../../hooks/useDatePickerInputCommon.js';
import { useDateRangePickerInput } from '../../hooks/useDateRangePickerInput.js';
import 'react-dropzone';
import 'uuid';
import '@floating-ui/react';
import 'currency.js';
import { RangeCalendar } from '../Calendar/RangeCalendar.js';
import { Popover } from '../Popover/index.js';
import { Content } from './Content.js';
import { DateField } from './DateField.js';
import { DatePickerInputBase } from './DatePickerInputBase.js';

const DateRangePickerInputWithPopover = (props) => {
  const {
    onChange,
    value,
    label,
    variants,
    disabled = false,
    hourCycle = 24,
    granularity = "day"
  } = props;
  const { endFieldProps, startFieldProps, ref, state } = useDateRangePickerInput({ value, onChange });
  const { handleTogglePopover, handleChangeCalendar, handleCloseCalendar } = useDatePickerInputCommon({
    onChangeRangeCalendar: (value2) => {
      state.setDateRange({
        start: dateToCalendarDateTime(value2?.start),
        end: dateToCalendarDateTime(value2?.end)
      });
    }
  });
  return /* @__PURE__ */ React__default.createElement("div", { ref, "data-testid": "date-range-picker-input" }, /* @__PURE__ */ React__default.createElement(Popover.Trigger, { disabled: true }, /* @__PURE__ */ React__default.createElement(
    DatePickerInputBase,
    {
      variants: {
        ...variants,
        intent: state.isInvalid ? "error" : variants?.intent
      },
      label,
      disabled,
      value,
      onClean: () => state.setValue(null),
      onToggle: handleTogglePopover
    },
    /* @__PURE__ */ React__default.createElement("div", { className: "flex flex-row gap-x-micro items-center" }, /* @__PURE__ */ React__default.createElement(
      DateField,
      {
        ...startFieldProps,
        onChange: (value2) => {
          startFieldProps.onChange?.(value2);
          handleCloseCalendar();
        },
        isDisabled: disabled,
        onClickDate: handleTogglePopover,
        hourCycle,
        granularity
      }
    ), /* @__PURE__ */ React__default.createElement("span", null, "-"), /* @__PURE__ */ React__default.createElement(
      DateField,
      {
        ...endFieldProps,
        onChange: (value2) => {
          endFieldProps.onChange?.(value2);
          handleCloseCalendar();
        },
        isDisabled: disabled,
        onClickDate: handleTogglePopover,
        hourCycle,
        granularity
      }
    ))
  )), /* @__PURE__ */ React__default.createElement(
    Popover.Content,
    {
      className: "bg-inherit shadow-none border-none",
      initialFocus: -1
    },
    /* @__PURE__ */ React__default.createElement(RangeCalendar, { value, onChange: handleChangeCalendar })
  ));
};
const DateRangePickerInput = (props) => /* @__PURE__ */ React__default.createElement(Popover.Root, { placement: "bottom-start", trigger: "click" }, /* @__PURE__ */ React__default.createElement(Content, null, /* @__PURE__ */ React__default.createElement(DateRangePickerInputWithPopover, { ...props })));

export { DateRangePickerInput };
