import React__default, { useEffect, useCallback } from 'react';
import '@internationalized/date';
import 'react-aria';
import 'react-stately';
import '../Popover/Context.js';
import 'react-dropzone';
import 'uuid';
import '@floating-ui/react';
import { useNumberMask } from '../../hooks/useNumberMask.js';
import { useStringMask } from '../../hooks/useStringMask.js';
import { InputRoot } from './Root.js';

const InputMask = React__default.forwardRef(
  ({ mask, onChange, value, ...rest }, ref) => {
    const getInputHook = (value2) => {
      if (mask !== void 0) {
        if (Array.isArray(mask) || typeof mask === "function") {
          return useStringMask(mask, value2);
        } else {
          return useNumberMask(mask, value2);
        }
      } else {
        return [void 0, void 0];
      }
    };
    const [maskValue, setMaskValue] = getInputHook(value ?? "");
    const _value = maskValue === void 0 ? value?.toString() : maskValue.formatted ? maskValue.formatted : "";
    useEffect(() => {
      if (onChange) {
        onChange(maskValue?.raw);
      }
    }, [maskValue]);
    const onChangeValue = useCallback(
      (value2) => {
        if (maskValue !== void 0 && setMaskValue !== void 0) {
          setMaskValue(value2);
        } else onChange?.(value2);
      },
      [value]
    );
    useEffect(() => {
      if (maskValue !== void 0 && setMaskValue !== void 0 && value !== void 0 && typeof maskValue === "object") {
        if (maskValue.raw !== void 0 && maskValue.raw.toString() !== value.toString()) {
          onChangeValue(value);
        }
      } else if (maskValue === void 0 && value !== void 0) {
        onChangeValue(value);
      }
    }, [value]);
    return /* @__PURE__ */ React__default.createElement(
      InputRoot,
      {
        ...rest,
        value: _value,
        onChange: (e) => onChangeValue(e.target.value),
        ref
      }
    );
  }
);

export { InputMask };
