import clsx from 'clsx';
import React__default, { useCallback } from 'react';
import '@internationalized/date';
import 'react-aria';
import 'react-stately';
import '../Popover/Context.js';
import 'react-dropzone';
import 'uuid';
import '@floating-ui/react';
import 'currency.js';
import '../../provider/MenubarContext.js';
import '../../provider/SnackbarProvider.js';
import { useMenubar } from '../../provider/useMenubar.js';
import { item } from '../../styles/menubar.js';
import IconControlSubItem from './IconControlSubItem.js';
import ItemLink from './ItemLink.js';
import { useCategories } from '../../provider/CategoriesContext.js';

const { container, textBehavior } = item();
const Item = ({
  children,
  subItems,
  renderSubItems,
  className,
  anchorProps,
  title,
  parentCategoryTitle,
  ...rest
}) => {
  const hasSubItems = (subItems ?? []).length > 0;
  const [, setShow] = useMenubar();
  const { expandedMenus, toggleSubmenu } = useCategories();
  const isExpanded = expandedMenus[parentCategoryTitle] === title;
  const handleClickItemMenubar = useCallback(
    (e) => {
      if (hasSubItems) {
        e.stopPropagation();
        toggleSubmenu(parentCategoryTitle, title);
      } else {
        setShow(false);
      }
    },
    [hasSubItems, parentCategoryTitle, title, toggleSubmenu, setShow]
  );
  return /* @__PURE__ */ React__default.createElement(ItemLink, { anchorProps }, /* @__PURE__ */ React__default.createElement(
    "div",
    {
      "data-testid": "item-menubar",
      ...rest,
      onClick: handleClickItemMenubar,
      className: clsx(
        container({ className }),
        (!hasSubItems || anchorProps) && textBehavior()
      )
    },
    children,
    hasSubItems ? /* @__PURE__ */ React__default.createElement(
      IconControlSubItem,
      {
        show: isExpanded,
        setShow: () => toggleSubmenu(parentCategoryTitle, title)
      }
    ) : null
  ), isExpanded ? /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, subItems?.map((subItem) => renderSubItems?.(subItem))) : null);
};

export { Item as default };
