import { selectVariants } from '@tecsinapse/cortex-core';
import React__default, { useContext, useCallback } from 'react';
import '@internationalized/date';
import 'react-aria';
import 'react-stately';
import { usePopoverContext } from '../Popover/Context.js';
import 'react-dropzone';
import 'uuid';
import '@floating-ui/react';
import 'currency.js';
import { useSelectGroupedOptions } from '../../hooks/useSelectGroupedOptions.js';
import { SelectOption } from './Option.js';
import { SkeletonOptions } from './SkeletonOptions.js';
import { SelectContext } from './context.js';

const { groupedTitle, list } = selectVariants();
const SelectGroupedOptions = ({
  onSelect,
  groupedLabelExtractor,
  options
}) => {
  const { keyExtractor } = useContext(SelectContext);
  const { setIsOpen } = usePopoverContext();
  const { options: _options, isLoading } = useSelectGroupedOptions({ options });
  const handleSelect = useCallback(
    (option) => {
      onSelect(option);
      setIsOpen?.(false);
    },
    [onSelect]
  );
  return isLoading ? /* @__PURE__ */ React__default.createElement(SkeletonOptions, null) : /* @__PURE__ */ React__default.createElement("ul", { role: "select", className: list() }, [..._options ?? []].map(([key, value]) => /* @__PURE__ */ React__default.createElement("div", { key }, /* @__PURE__ */ React__default.createElement("span", { className: groupedTitle() }, groupedLabelExtractor?.(key)), value.map((option) => /* @__PURE__ */ React__default.createElement(
    SelectOption,
    {
      grouped: true,
      option,
      key: keyExtractor(option),
      onSelectOption: handleSelect
    }
  )))));
};

export { SelectGroupedOptions };
