import { selectVariants } from '@tecsinapse/cortex-core';
import React__default, { useContext, useMemo } from 'react';
import '@internationalized/date';
import 'react-aria';
import 'react-stately';
import '../Popover/Context.js';
import 'react-dropzone';
import 'uuid';
import '@floating-ui/react';
import 'currency.js';
import { useSelectGroupedOptions } from '../../hooks/useSelectGroupedOptions.js';
import { SelectMultiOption } from './MultiOption.js';
import { SkeletonOptions } from './SkeletonOptions.js';
import { SelectContext, SelectMultiOptionsContext } from './context.js';
import { handleSelectMulti } from './utils.js';

const { groupedTitle, list } = selectVariants();
const SelectMultiGroupedOptions = ({
  onSelect,
  groupedLabelExtractor,
  options,
  children
}) => {
  const { value: currentValue = [], keyExtractor } = useContext(SelectContext);
  const { options: _options, isLoading } = useSelectGroupedOptions({ options });
  const flattenMap = useMemo(
    () => _options ? Array.from(_options?.values()).flatMap((value) => value) : [],
    [_options]
  );
  return /* @__PURE__ */ React__default.createElement(
    SelectMultiOptionsContext.Provider,
    {
      value: { onSelect, options: flattenMap }
    },
    children,
    isLoading ? /* @__PURE__ */ React__default.createElement(SkeletonOptions, null) : /* @__PURE__ */ React__default.createElement("ul", { role: "select", className: list() }, [..._options ?? []].map(([key, value]) => /* @__PURE__ */ React__default.createElement("div", { key }, /* @__PURE__ */ React__default.createElement("span", { className: groupedTitle() }, groupedLabelExtractor?.(key)), value.map((option) => /* @__PURE__ */ React__default.createElement(
      SelectMultiOption,
      {
        grouped: true,
        option,
        key: keyExtractor(option),
        onSelectOption: (option2) => handleSelectMulti(
          option2,
          currentValue,
          onSelect,
          keyExtractor
        )
      }
    )))))
  );
};

export { SelectMultiGroupedOptions };
