import { option, checkbox } from '@tecsinapse/cortex-core';
import React__default, { useContext, useRef, useMemo, useCallback } from 'react';
import { SelectContext } from './context.js';

const SelectMultiOption = ({
  onSelectOption,
  option: option$1,
  grouped = false
}) => {
  const { keyExtractor, labelExtractor, value } = useContext(SelectContext);
  const inputRef = useRef(null);
  const isChecked = useMemo(
    () => value?.length > 0 && value.find((it) => keyExtractor(it) === keyExtractor(option$1)) !== void 0,
    [value, option$1]
  );
  const onClickOption = useCallback(() => {
    onSelectOption(option$1);
    inputRef.current?.click();
  }, [onSelectOption, inputRef]);
  return /* @__PURE__ */ React__default.createElement(
    "li",
    {
      onClick: onClickOption,
      className: option({ grouped }),
      role: "option"
    },
    /* @__PURE__ */ React__default.createElement(
      "input",
      {
        type: "checkbox",
        checked: isChecked,
        className: checkbox({ className: "pointer-events-none" }),
        onChange: () => false,
        ref: inputRef
      }
    ),
    labelExtractor(option$1)
  );
};

export { SelectMultiOption };
