import React__default, { useContext, useRef, useMemo, useEffect } from 'react';
import { IoChevronDownOutline } from 'react-icons/io5';
import { Popover } from '../Popover/index.js';
import { SelectContext } from './context.js';
import clsx from 'clsx';
import { selectVariants, labelStyle } from '@tecsinapse/cortex-core';

const { button } = selectVariants();
const SelectTrigger = ({
  label,
  placeholder,
  disabled,
  multiLabelSelected,
  ...rest
}) => {
  const { value, labelExtractor, setTriggerWidth } = useContext(SelectContext);
  const triggerRef = useRef(null);
  const _placeholder = useMemo(() => {
    if (value?.length === 0 || !value) return placeholder ?? label;
    if (value?.length === 1) return labelExtractor(value[0]);
    if (value?.length > 1)
      return multiLabelSelected ? multiLabelSelected(value.length) : `${value.length} items selected`;
    return labelExtractor(value);
  }, [label, value]);
  const hasValue = Array.isArray(value) ? value.length > 0 : !!value;
  useEffect(() => {
    if (triggerRef.current && setTriggerWidth) {
      const width = triggerRef.current.getBoundingClientRect().width;
      setTriggerWidth(width);
    }
  }, [triggerRef.current, setTriggerWidth]);
  return /* @__PURE__ */ React__default.createElement(Popover.Trigger, { disabled }, /* @__PURE__ */ React__default.createElement("div", { className: "w-full gap-mili" }, /* @__PURE__ */ React__default.createElement(
    "button",
    {
      ref: triggerRef,
      className: button({ className: rest.className }),
      disabled,
      role: "button",
      ...rest
    },
    /* @__PURE__ */ React__default.createElement(
      "span",
      {
        className: clsx({ "mt-mili": hasValue && label }),
        "data-testid": "select-placeholder"
      },
      _placeholder
    ),
    /* @__PURE__ */ React__default.createElement(IoChevronDownOutline, null)
  ), hasValue && label ? /* @__PURE__ */ React__default.createElement(
    "label",
    {
      htmlFor: "select-trigger",
      className: clsx(
        "ml-centi",
        labelStyle({ intent: "default", placeholder })
      ),
      "data-testid": "input-label"
    },
    label
  ) : null));
};

export { SelectTrigger };
