import React__default, { useMemo, useState, useCallback } from 'react';
import { Node } from './Node.js';
import clsx from 'clsx';

const Root = ({
  segmented = false,
  children,
  className = "",
  interactive = true
}) => {
  const initialSelectedIndex = useMemo(() => {
    let initialIndex = null;
    React__default.Children.forEach(children, (child, index) => {
      if (React__default.isValidElement(child) && child.props.selected) {
        initialIndex = index;
      }
    });
    return initialIndex;
  }, [children]);
  const [selectedNode, setSelectedNode] = useState(
    initialSelectedIndex
  );
  const childrenCount = useMemo(
    () => React__default.Children.count(children),
    [children]
  );
  const handleNodeClick = useCallback(
    (index, onClick) => {
      if (interactive) {
        setSelectedNode(index);
        if (onClick) {
          onClick();
        }
      }
    },
    [interactive]
  );
  const renderNode = useMemo(
    () => (child, index) => {
      if (React__default.isValidElement(child) && child.type === Node) {
        return React__default.cloneElement(child, {
          isFirst: index === 0,
          isLast: index === childrenCount - 1,
          selected: selectedNode === index,
          segmented,
          interactive,
          onClick: () => handleNodeClick(index, child.props.onClick)
        });
      }
      return null;
    },
    [childrenCount, selectedNode, segmented, interactive]
  );
  return /* @__PURE__ */ React__default.createElement(
    "div",
    {
      className: clsx(
        "flex w-full space-x-2 bg-white p-4 pb-2 rounded-mili",
        className
      )
    },
    React__default.Children.map(children, renderNode)
  );
};

export { Root };
