import { isSameDay } from '@internationalized/date';
import { useRef } from 'react';
import { useCalendarCell as useCalendarCell$1 } from 'react-aria';

const useCalendarCell = ({ state, date }) => {
  const ref = useRef(null);
  const {
    cellProps,
    buttonProps,
    isSelected,
    isOutsideVisibleRange,
    formattedDate
  } = useCalendarCell$1({ date }, state, ref);
  const rangeStateHighlitedRange = state?.highlightedRange;
  const isSameDayStart = rangeStateHighlitedRange && date ? isSameDay(date, rangeStateHighlitedRange.start) : void 0;
  const isSameDayEnd = rangeStateHighlitedRange && date ? isSameDay(date, rangeStateHighlitedRange.end) : void 0;
  const isSelectionStart = isSameDayStart && !isSameDayEnd;
  const isSelectionEnd = isSameDayEnd && !isSameDayStart;
  const inRange = rangeStateHighlitedRange && date > rangeStateHighlitedRange?.start && date < rangeStateHighlitedRange?.end;
  return {
    ref,
    cellProps,
    buttonProps,
    isSelected,
    isOutsideVisibleRange,
    formattedDate,
    isSelectionStart,
    isSelectionEnd,
    inRange: Boolean(inRange)
  };
};

export { useCalendarCell };
