import { useRef, useEffect } from 'react';
import { useDatePicker } from 'react-aria';
import { useDatePickerState } from 'react-stately';
import { dateToCalendarDateTime, calendarDateToDate } from '../utils/date.js';

const useDatePickerInput = ({
  value,
  onChange
}) => {
  const state = useDatePickerState({
    defaultValue: value ? dateToCalendarDateTime(value) : null,
    onChange: (value2) => {
      onChange(calendarDateToDate(value2));
    }
  });
  const ref = useRef(null);
  const { fieldProps } = useDatePicker(
    { "aria-label": "date-picker-field" },
    state,
    ref
  );
  useEffect(() => {
    if (!value) {
      state.setValue(null);
    }
  }, [value]);
  return {
    fieldProps,
    state,
    ref
  };
};

export { useDatePickerInput };
