import { useRef } from 'react';
import { useDateRangePicker } from 'react-aria';
import { useDateRangePickerState } from 'react-stately';
import { dateToCalendarDateTime, calendarDateToDate } from '../utils/date.js';

const useDateRangePickerInput = ({
  value,
  onChange
}) => {
  const state = useDateRangePickerState({
    defaultValue: value ? {
      start: dateToCalendarDateTime(value?.start),
      end: dateToCalendarDateTime(value?.end)
    } : null,
    onChange: (value2) => {
      onChange({
        start: value2 ? calendarDateToDate(value2.start) : void 0,
        end: value2 ? calendarDateToDate(value2.end) : void 0
      });
    }
  });
  const ref = useRef(null);
  const { startFieldProps, endFieldProps } = useDateRangePicker(
    { "aria-label": "date-range-picker-field" },
    state,
    ref
  );
  return {
    startFieldProps,
    endFieldProps,
    state,
    ref
  };
};

export { useDateRangePickerInput };
