import { useRef, useState, useEffect } from 'react';

function useDebouncedState(initialState, timeoutCallback, timeoutMs = 166) {
  const timeoutId = useRef();
  const [state, setState] = useState(initialState);
  useEffect(() => {
    if (timeoutId.current) clearTimeout(timeoutId.current);
    if (timeoutCallback)
      timeoutId.current = setTimeout(() => timeoutCallback(state), timeoutMs);
  }, [state]);
  return [state, setState];
}

export { useDebouncedState };
