import { useFloating, autoUpdate, offset, flip, shift, arrow, useClick, useDismiss, useRole, useHover, safePolygon, useInteractions } from '@floating-ui/react';
import { useState, useEffect } from 'react';

const useFloatingElement = ({
  placement,
  trigger,
  delay,
  arrowRef,
  controlled,
  isOpen,
  setIsOpen,
  fallbackPlacements = ["right", "bottom", "left", "top"]
}) => {
  const [openUncontrolled, onOpenChangeUncontrolled] = useState(false);
  const { x, y, strategy, refs, update, context, floatingStyles } = useFloating(
    {
      placement,
      whileElementsMounted: autoUpdate,
      open: controlled ? isOpen : openUncontrolled,
      onOpenChange: controlled ? setIsOpen : onOpenChangeUncontrolled,
      middleware: [
        offset(10),
        flip({
          flipAlignment: true,
          fallbackPlacements
        }),
        shift(),
        ...arrowRef ? [arrow({ element: arrowRef })] : []
      ]
    }
  );
  const click = useClick(context, { enabled: trigger === "click" });
  const dismiss = useDismiss(context);
  const role = useRole(context);
  const hover = useHover(context, {
    enabled: trigger === "hover",
    delay,
    handleClose: safePolygon()
  });
  const { getReferenceProps, getFloatingProps } = useInteractions([
    click,
    dismiss,
    role,
    hover
  ]);
  useEffect(() => {
    if (controlled && isOpen) update();
    else if (openUncontrolled) update();
  }, [openUncontrolled, update, isOpen]);
  const triggerProps = {
    ref: refs.setReference,
    ...getReferenceProps()
  };
  return {
    isOpen: controlled ? isOpen : openUncontrolled,
    setIsOpen: controlled ? setIsOpen : onOpenChangeUncontrolled,
    x,
    y,
    strategy,
    refs,
    context,
    floatingStyles,
    triggerProps,
    getReferenceProps,
    getFloatingProps
  };
};

export { useFloatingElement };
