import { useCallback, useEffect } from 'react';

const useOutsideClickListener = ({
  ref,
  onClickOutside
}) => {
  const handleClickOutside = useCallback((event) => {
    if (ref.current && !ref.current.contains(event.composedPath()[0])) {
      onClickOutside?.();
    }
  }, []);
  useEffect(() => {
    document.addEventListener("click", handleClickOutside, true);
    return () => {
      document.removeEventListener("click", handleClickOutside, true);
    };
  }, [handleClickOutside]);
};

export { useOutsideClickListener };
