import { createCalendar } from '@internationalized/date';
import { useRef } from 'react';
import { useLocale, useRangeCalendar as useRangeCalendar$1 } from 'react-aria';
import { useRangeCalendarState } from 'react-stately';
import { dateToCalendarDateTime, calendarDateToDate } from '../utils/date.js';

const useRangeCalendar = ({
  value,
  onChange
}) => {
  const { locale } = useLocale();
  const state = useRangeCalendarState({
    locale,
    createCalendar,
    defaultValue: {
      start: dateToCalendarDateTime(value?.start),
      end: dateToCalendarDateTime(value?.end)
    },
    onChange: (value2) => onChange({
      start: calendarDateToDate(value2.start),
      end: calendarDateToDate(value2.end)
    })
  });
  const ref = useRef(null);
  const { calendarProps, title } = useRangeCalendar$1({}, state, ref);
  return {
    calendarProps,
    title,
    state,
    ref
  };
};

export { useRangeCalendar };
