import { useState, useCallback, useEffect } from 'react';

const useSelectOptions = ({
  options: _options
}) => {
  const [options, setOptions] = useState();
  const [isLoading, setIsLoading] = useState();
  const [error, setError] = useState();
  const initData = useCallback(async (fetch) => {
    setIsLoading(true);
    try {
      const result = await fetch();
      if (result) {
        setOptions(result ?? []);
      }
    } catch (e) {
      setError(String(e));
    } finally {
      setIsLoading(false);
    }
  }, []);
  useEffect(() => {
    if (typeof _options === "function") initData(_options);
    else setOptions(_options);
  }, [_options]);
  return {
    isLoading,
    options,
    error
  };
};

export { useSelectOptions };
