import { useState, useCallback } from 'react';

const mergeMask = (value = "", mask) => {
  let formatted = "";
  let raw = "";
  let iMask = 0;
  let iChars = 0;
  while (!(iMask === mask.length || iChars === value.length)) {
    const maskChar = mask[iMask];
    const valueChar = value[iChars];
    if (maskChar === valueChar) {
      formatted += maskChar;
      iChars++;
      iMask++;
      continue;
    }
    const rawValueChar = value[iChars];
    if (typeof maskChar === "object") {
      iChars++;
      const maskCharRegex = Array.isArray(maskChar) ? maskChar[0] : maskChar;
      const matchRegex = RegExp(maskCharRegex).test(valueChar);
      if (matchRegex) {
        formatted += valueChar;
        raw += rawValueChar;
        iMask++;
      }
    } else {
      formatted += maskChar;
      iMask++;
    }
  }
  return { raw, formatted };
};
const getMask = (mask, newValue) => {
  let maskArray;
  const regexArray = [];
  if (typeof mask === "function") {
    maskArray = mask(newValue);
  } else {
    maskArray = mask;
  }
  maskArray.forEach((exp) => {
    if (typeof exp !== "string") {
      if (Array.isArray(exp)) regexArray.push(exp);
      else regexArray.push(exp);
    } else {
      for (let i = 0; i < exp.length; i++) {
        if (exp[i] === "\\") {
          regexArray.push(exp[i + 1]);
          i++;
        } else {
          if (exp[i] === "9") regexArray.push(/\d/);
          else if (exp[i] === "a") regexArray.push(/[a-zA-Z]/);
          else regexArray.push(exp[i]);
        }
      }
    }
  });
  return regexArray;
};
const applyStringMask = (value, mask) => {
  const selectedMask = getMask(mask, value);
  return mergeMask(value, selectedMask);
};
const useStringMask = (mask, defaultValue) => {
  const [value, setValue] = useState(
    applyStringMask(String(defaultValue ?? ""), mask)
  );
  const handleChangeValue = useCallback(
    (formattedValue) => {
      const { raw, formatted } = applyStringMask(String(formattedValue), mask);
      setValue({
        raw,
        formatted
      });
    },
    [setValue]
  );
  return [value, handleChangeValue];
};

export { applyStringMask, getMask, mergeMask, useStringMask };
